#include <bits/stdc++.h>

using namespace std;

typedef long long ll;
typedef long double ld;

struct Point;
struct Line;

struct Point {
    ld x, y;
    Point() {}
    Point(ld x, ld y): x(x), y(y) {};
    Point operator+(const Point &other) const {return Point(x + other.x, y + other.y);}
    Point operator-(const Point &other) const {return Point(x - other.x, y - other.y);}
    Point operator*(const ld &other) const {return Point(x * other, y * other);}
    ld dot(const Point &other) const {return x * other.x + y * other.y;}
    ld cross(const Point &other) const {return x*other.y - y*other.x;}
    ld length() const {return sqrt(x*x + y*y);}

    Point flip_along(Line l);
};

struct Line {
    Point A, B;
    Line() {}
    Line(Point& A, Point& B): A(A), B(B) {}
    Line(ld Ax, ld Ay, ld Bx, ld By) {
        A = Point(Ax, Ay);
        B = Point(Bx, By);
    }
    bool intersects_segment(Line& s) {
        return (B - A).cross(s.A - A) * (B - A).cross(s.B - A) < 0;
    }
    void flip_along(Line& l) {
        A = A.flip_along(l);
        B = B.flip_along(l);
    }
};

Point Point::flip_along(Line l){
    Point alfa = l.B - l.A;
    Point beta = *this - l.A;
    Point X = l.A + (alfa * (alfa.dot(beta) / alfa.length()));
    return X - (*this - X);
}


int n;
Point S, E;
vector<Line> lines;
vector<ld> solutions;

struct Instance {
    vector<Line> lines;
    Point destination;
    int reflecting;

    Instance(vector<Line>& lines, Point &destination, int reflecting)
    :lines(lines), destination(destination), reflecting(reflecting) {}

    Instance flip_along_line(int i) {
        Instance new_instance(lines, destination, i+1);
        for (int j=i+1; j<n; j++) {
            new_instance.lines[j].flip_along(new_instance.lines[i]);
        }
        new_instance.destination = new_instance.destination.flip_along(new_instance.lines[i]);
        return new_instance;
    }

    bool check_intersections() {
        Line segment(S, destination);
        for (int i=0; i<reflecting; i++) {
            if (!lines[i].intersects_segment(segment)) return false;
        }
        for (int i=reflecting; i<n; i++) {
            if (lines[i].intersects_segment(segment)) return false;
        }
        return true;
        // Maybe TODO: check intersection of 2 mirrors?
    }

    ld get_direction() {
        Point dir = destination - S;
        return atan2(dir.y, dir.x);
    }
};

vector<Instance> prepare_instances(vector<int> &order) {
    vector<Line> init_lines;
    for (int i=0; i<n; i++) {
        init_lines.push_back(lines[order[i]]);
    }
    vector<Instance> instances;
    instances.push_back(Instance(init_lines, E, 0));
    for (int i=0; i<n; i++) {
        instances.push_back(
            instances.back().flip_along_line(i)
        );
    }
    return instances;
}


int main() {
    scanf(" %d", &n);
    int sx, sy, ex, ey;
    scanf(" %d %d %d %d", &sx, &sy, &ex, &ey);
    S = Point(sx, sy);
    E = Point(ex, ey);
    for (int i=0; i<n; i++) {
        int ax, ay, bx, by;
        scanf(" %d %d %d %d", &ax, &ay, &bx, &by);
        lines.push_back(Line(ax, ay, bx, by));
    }

    vector<int> order;
    for(int i=0; i<n; i++) order.push_back(i);
    do {
        vector<Instance> instances = prepare_instances(order);
        for (Instance& instance : instances) {
            if (!instance.check_intersections()) continue;
            solutions.push_back(instance.get_direction());
        }
    } while (next_permutation(order.begin(), order.end()));

    sort(solutions.begin(), solutions.end());
    int distinct = ((solutions.size() > 0) ? 1 : 0);
    for(int i=1; i<solutions.size(); i++) {
        if (abs(solutions[i] - solutions[i-1]) > 1e-4) distinct++;
    }
    printf("%d\n", distinct);

    return 0;
}

